@@ -202,13 +202,22 @@ def escape_attribute_value(text):
         return text
 
 
-def tiddler_url(environ, tiddler):
+def tiddler_url(environ, tiddler, container='bags', full=True):
     """
-    Construct a URL for a tiddler.
+    Construct a URL for a tiddler. If the tiddler has a _canonical_uri
+    field, use that instead.
     """
-    tiddler_link = 'bags/%s/tiddlers/%s' % (encode_name(tiddler.bag),
-            encode_name(tiddler.title))
-    return '%s/%s' % (server_base_url(environ), tiddler_link)
+    if '_canonical_uri' in tiddler.fields:
+        return tiddler.fields['_canonical_uri']
+
+    container_name = tiddler.recipe if container == 'recipes' else tiddler.bag
+    tiddler_link = '%s/%s/tiddlers/%s' % (container,
+            encode_name(container_name), encode_name(tiddler.title))
+
+    if full:
+        return '%s/%s' % (server_base_url(environ), tiddler_link)
+    else:
+        return '%s/%s' % (_server_prefix(environ), tiddler_link)
 
 
 def recipe_url(environ, recipe):
